
package com.tmerclub.cloud.multishop.dto;

import io.swagger.v3.oas.annotations.media.Schema;
import jakarta.validation.constraints.Max;
import jakarta.validation.constraints.Min;
import org.springframework.format.annotation.DateTimeFormat;

import java.io.Serial;
import java.io.Serializable;
import java.util.Date;

/**
 * 工商信息审核记录
 *
 * @author chiley
 * @date 2022/9/1 16:15
 */

public class ShopCompanyAuditingDTO implements Serializable {
    @Serial
    private static final long serialVersionUID = 1L;
    /**
     * 工商信息审核id
     */
    private Long companyAuditingId;

    /**
     * 申请人id
     */
    @Schema(description = "申请人id")
    private Long userId;

    /**
     * 店铺id
     */
    @Schema(description = "店铺id")
    private Long shopId;


    /**
     * 工商信息id
     */
    @Schema(description = "工商信息id")
    private Long shopCompanyId;

    /**
     * 店铺名称
     */
    @Schema(description = "店铺名称")
    private String shopName;

    /**
     * 审核人id
     */
    @Schema(description = "审核人id")
    private Long auditorId;

    /**
     * 0 未审核 1已通过 -1未通过
     */
    @Schema(description = "0 未审核 1已通过 -1未通过")
    @Max(value = 1, message = "最大为1")
    @Min(value = -1, message = "最小为-1")
    private Integer status;

    @Schema(description = "申请起始时间")
    @DateTimeFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    private Date beginTime;

    @Schema(description = "申请结束时间")
    @DateTimeFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    private Date endTime;

    @Schema(description = "备注")
    private String remarks;

    public ShopCompanyAuditingDTO() {

    }

    public ShopCompanyAuditingDTO(Long companyAuditingId, Integer status, String remarks) {
        this.companyAuditingId = companyAuditingId;
        this.status = status;
        this.remarks = remarks;
    }

    public Long getCompanyAuditingId() {
        return companyAuditingId;
    }

    public void setCompanyAuditingId(Long companyAuditingId) {
        this.companyAuditingId = companyAuditingId;
    }

    public Long getUserId() {
        return userId;
    }

    public void setUserId(Long userId) {
        this.userId = userId;
    }

    public Long getShopId() {
        return shopId;
    }

    public void setShopId(Long shopId) {
        this.shopId = shopId;
    }

    public Long getShopCompanyId() {
        return shopCompanyId;
    }

    public void setShopCompanyId(Long shopCompanyId) {
        this.shopCompanyId = shopCompanyId;
    }

    public String getShopName() {
        return shopName;
    }

    public void setShopName(String shopName) {
        this.shopName = shopName;
    }

    public Long getAuditorId() {
        return auditorId;
    }

    public void setAuditorId(Long auditorId) {
        this.auditorId = auditorId;
    }

    public Integer getStatus() {
        return status;
    }

    public void setStatus(Integer status) {
        this.status = status;
    }

    public Date getBeginTime() {
        return beginTime;
    }

    public void setBeginTime(Date beginTime) {
        this.beginTime = beginTime;
    }

    public Date getEndTime() {
        return endTime;
    }

    public void setEndTime(Date endTime) {
        this.endTime = endTime;
    }

    public String getRemarks() {
        return remarks;
    }

    public void setRemarks(String remarks) {
        this.remarks = remarks;
    }

    @Override
    public String toString() {
        return "ShopCompanyAuditingDTO{" +
                "companyAuditingId=" + companyAuditingId +
                ", userId='" + userId + '\'' +
                ", shopId=" + shopId +
                ", shopCompanyId=" + shopCompanyId +
                ", shopName='" + shopName + '\'' +
                ", auditorId=" + auditorId +
                ", status=" + status +
                ", beginTime=" + beginTime +
                ", endTime=" + endTime +
                ", remarks='" + remarks + '\'' +
                '}';
    }
}
