
package com.tmerclub.cloud.delivery.service;

import com.tmerclub.cloud.api.delivery.dto.StationSalesDTO;
import com.tmerclub.cloud.api.delivery.vo.StationVO;
import com.tmerclub.cloud.common.database.dto.PageDTO;
import com.tmerclub.cloud.common.database.vo.PageVO;
import com.tmerclub.cloud.common.order.vo.OrderSelfStationVO;
import com.tmerclub.cloud.common.order.vo.UserDeliveryInfoVO;
import com.tmerclub.cloud.delivery.dto.OrderStationDTO;
import com.tmerclub.cloud.common.order.vo.OrderStationSpuDTO;
import com.tmerclub.cloud.delivery.dto.StationDTO;
import com.tmerclub.cloud.delivery.model.Station;
import com.tmerclub.cloud.order.vo.StationDetailVO;

import java.util.List;

/**
 * 自提点信息
 *
 * @author tmerclub
 * @date 2020-12-07 15:10:01
 */
public interface StationService {

    /**
     * 分页获取自提点信息列表
     * @param pageDTO 分页参数
     * @return 自提点信息列表分页数据
     */
    PageVO<StationVO> page(PageDTO pageDTO);

    /**
     * 分页获取自提点列表
     * @param pageDTO
     * @param stationDTO
     * @return
     */
    PageVO<StationVO> pageStation(PageDTO pageDTO, StationDTO stationDTO);

    /**
     * 根据自提点信息id获取自提点信息
     *
     * @param stationId 自提点信息id
     * @return 自提点信息
     */
    StationVO getByStationId(Long stationId);

    /**
     * 保存自提点信息
     * @param station 自提点信息
     */
    void save(Station station);

    /**
     * 更新自提点信息
     * @param station 自提点信息
     */
    void update(Station station);

    /**
     * 根据自提点信息id删除自提点信息
     * @param stationId
     */
    void deleteById(Long stationId);

    /**
     * 根据自提点id删除自提点（逻辑删除）
     * @param stationId
     */
    void logicDeleteById(Long stationId);

    /**
     * 统计门店销售数据
     * @param shopId
     * @param stationId
     * @return
     */
    List<StationSalesDTO> getStationSalesRecord(Long shopId, Long stationId);


    /**
     * 分页获取用户常用自提门店以及由近及远的自提门店列表
     * @param page 分页参数
     * @param orderStationDTO 自提门店筛选参数
     * @return 分页用户常用自提门店以及由近及远的自提门店列表
     */
    PageVO<StationDetailVO> getStationList(PageDTO page, OrderStationDTO orderStationDTO);


    /**
     * 获取自提门店详情
     * @param stationId 自提门店id
     * @return 门店详情
     */
    StationVO getStationInfoById(Long stationId);

    /**
     * 获取门店距离
     * @param stationId 自提点id
     * @param lat 维度
     * @param lng 经度
     * @return
     */
    Double getStationDistance(Long stationId, Double lat, Double lng);

    /**
     * 获取自提点列表
     * @param stationIds
     * @return
     */
    List<StationVO> listByStationId(List<Long> stationIds);

    /**
     * 根据店铺id获取自提点
     * @param shopId
     * @return
     */
    List<StationVO> listByShopId(Long shopId);

    /**
     * 切换门店库存模式
     * @param stationId
     * @param type 共享库存模式（1同步到默认仓库 2库存清零），只有切换成共享库存模式才有值
     */
    void switchStationStockMode(Long stationId, Integer type);

    /**
     * 获取自提订单的门店数据 - 仅订单stationId为null时，获取距离用户最近的门店，如果没有传经纬度，则是返回一个有库存的门店
     * @param userDeliveryInfoVO
     * @param orderStationSpuList
     * @return
     */
    OrderSelfStationVO getOrderStation(UserDeliveryInfoVO userDeliveryInfoVO, List<OrderStationSpuDTO> orderStationSpuList);
}
