
package com.tmerclub.cloud.order.dto.app;

import io.swagger.v3.oas.annotations.media.Schema;
import jakarta.validation.constraints.NotEmpty;
import jakarta.validation.constraints.NotNull;
import org.hibernate.validator.constraints.Length;

import java.io.Serial;
import java.io.Serializable;

/**
 * @author tmerclub
 * @date 2021/3/9
 */
public class OrderRefundDeliveryDTO implements Serializable {
    @Serial
    private static final long serialVersionUID = 1L;
    @Schema(description = "退款编号名称", requiredMode = Schema.RequiredMode.REQUIRED)
    @NotNull(message = "退款编号不能为空")
    private Long refundId;

    @Schema(description = "物流公司ID", requiredMode = Schema.RequiredMode.REQUIRED)
    @NotNull
    private Long deliveryCompanyId;

    @Schema(description = "物流公司名称", requiredMode = Schema.RequiredMode.REQUIRED)
    @NotEmpty
    private String deliveryName;

    @Schema(description = "物流单号", requiredMode = Schema.RequiredMode.REQUIRED)
    @NotEmpty
    @Length(max = 50, message = "物流单号长度不能超过50")
    private String deliveryNo;

    @Schema(description = "手机号码", requiredMode = Schema.RequiredMode.REQUIRED)
    @NotEmpty
    @Length(max = 11, message = "手机号码长度不能超过11")
    private String mobile;

    @Schema(description = "备注信息")
    @Length(max = 255, message = "备注信息长度不能超过255")
    private String senderRemarks;

    @Schema(description = "图片举证")
    private String imgs;

    public Long getRefundId() {
        return refundId;
    }

    public void setRefundId(Long refundId) {
        this.refundId = refundId;
    }

    public Long getDeliveryCompanyId() {
        return deliveryCompanyId;
    }

    public void setDeliveryCompanyId(Long deliveryCompanyId) {
        this.deliveryCompanyId = deliveryCompanyId;
    }

    public String getDeliveryName() {
        return deliveryName;
    }

    public void setDeliveryName(String deliveryName) {
        this.deliveryName = deliveryName;
    }

    public String getDeliveryNo() {
        return deliveryNo;
    }

    public void setDeliveryNo(String deliveryNo) {
        this.deliveryNo = deliveryNo;
    }

    public String getMobile() {
        return mobile;
    }

    public void setMobile(String mobile) {
        this.mobile = mobile;
    }

    public String getSenderRemarks() {
        return senderRemarks;
    }

    public void setSenderRemarks(String senderRemarks) {
        this.senderRemarks = senderRemarks;
    }

    public String getImgs() {
        return imgs;
    }

    public void setImgs(String imgs) {
        this.imgs = imgs;
    }

    @Override
    public String toString() {
        return "OrderRefundDeliveryDTO{" +
                "refundId=" + refundId +
                ", deliveryCompanyId=" + deliveryCompanyId +
                ", deliveryName='" + deliveryName + '\'' +
                ", deliveryNo='" + deliveryNo + '\'' +
                ", mobile='" + mobile + '\'' +
                ", senderRemarks='" + senderRemarks + '\'' +
                ", imgs='" + imgs + '\'' +
                '}';
    }
}
