
package com.tmerclub.cloud.product.mapper;

import com.tmerclub.cloud.product.dto.TakeStockDTO;
import com.tmerclub.cloud.product.model.TakeStock;
import com.tmerclub.cloud.product.vo.TakeStockExcelVO;
import com.tmerclub.cloud.product.vo.TakeStockVO;
import org.apache.ibatis.annotations.Param;

import java.util.List;

/**
 * @author lhd
 * @date 2022-06-22 16:57:27
 */
public interface TakeStockMapper {

    /**
     * 获取列表
     *
     * @return 列表
     */
    List<TakeStock> list(@Param("takeStockDTO") TakeStockDTO takeStockDTO);

    /**
     * 根据id获取
     *
     * @param takeStockId id
     * @return
     */
    TakeStock getByTakeStockId(@Param("takeStockId") Long takeStockId);

    /**
     * 保存
     *
     * @param takeStock
     */
    void save(@Param("takeStock") TakeStock takeStock);

    /**
     * 更新
     *
     * @param takeStock
     */
    void update(@Param("takeStock") TakeStock takeStock);

    /**
     * 根据id删除
     *
     * @param takeStockId
     */
    void deleteById(@Param("takeStockId") Long takeStockId);

    /**
     * 通过参数分页查找
     *
     * @param lang
     * @param takeStockDTO
     * @return
     */
    List<TakeStockVO> pageByParam(@Param("lang") Integer lang, @Param("takeStockDTO") TakeStockDTO takeStockDTO);

    /**
     * 获取实物盘点导出数据
     *
     * @param takeStockDTO
     * @param lang
     * @return
     */
    List<TakeStockExcelVO> listTakeStockExportData(@Param("takeStockDTO") TakeStockDTO takeStockDTO, @Param("lang") Integer lang);

    /**
     * 统计未完成的实物盘点数
     * @param warehouseId 仓库id
     * @return 未完成数
     */
    Long countUnFinish(@Param("warehouseId") Long warehouseId);
}
